pub struct StatementReceiptOutcome {Show 18 fields
pub index: usize,
pub encoded_receipt: Vec<u8>,
pub structure: InspectionFinding,
pub required_claims: InspectionFinding,
pub support: InspectionFinding,
pub selected_policy: InspectionFinding,
pub claims: Option<UnauthenticatedReceiptClaims>,
pub candidate_derivation: InspectionFinding,
pub key_configuration: Vec<InspectionFinding>,
pub candidate_keys: Vec<VerifyingKeyEvidence>,
pub proofs: Vec<ProofVerification>,
pub signature_attempts: usize,
pub ts_signature: InspectionFinding,
pub inclusion: InspectionFinding,
pub ts_key_association: InspectionFinding,
pub ts_identity_trust: InspectionFinding,
pub acceptable_for_registration: InspectionFinding,
pub subject_policy: InspectionFinding,
}Expand description
Owned per-Receipt findings, preserving every encoded input and proof outcome. No borrowed self-reference and no collapsing a bad attachment into absence.
Fields
index: usizeencoded_receipt: Vec<u8>structure: InspectionFindingrequired_claims: InspectionFindingsupport: InspectionFindingselected_policy: InspectionFindingclaims: Option<UnauthenticatedReceiptClaims>candidate_derivation: InspectionFindingkey_configuration: Vec<InspectionFinding>candidate_keys: Vec<VerifyingKeyEvidence>proofs: Vec<ProofVerification>signature_attempts: usizets_signature: InspectionFindinginclusion: InspectionFindingts_key_association: InspectionFindingts_identity_trust: InspectionFindingacceptable_for_registration: InspectionFindingsubject_policy: InspectionFindingTrait Implementations
Sourceimpl Clone for StatementReceiptOutcome
impl Clone for StatementReceiptOutcome